.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mar 11 nov 2008 23:12:11 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

==========
 Stampati
==========

.. _concorrenti:

Concorrenti
===========

.. figure:: concorrenti.png


.. _tessere:

Tessere
=======

.. figure:: tesserefinali.png


.. _cartellini:

Cartellini
==========

.. figure:: cartellinifinali.png


.. _risultati:

Risultati
=========

.. figure:: risultati.png


.. _classifica:

Classifica
==========

.. figure:: classifica.png
